@@ -17,7 +17,7 @@ use Rose::Object::MakeMethods::Generic (
     boolean                 => [ 'tt' => { default => 1 }, ]
 );
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 =head1 NAME
 
@@ -329,21 +329,21 @@ sub make_catalyst {
     my $css_crud_dir = dir( $css_dir, 'crud' );
     $css_crud_dir->mkpath(1);
 
-    copy( file( $cx_crud_yui_tt_path, 'static', 'js', 'crud.js' ),
-        file( $js_dir, 'crud.js' ) )
+    copy( file( $cx_crud_yui_tt_path, 'static', 'js', 'crud.js' ) . '',
+        file( $js_dir, 'crud.js' ) . '' )
         or warn "ERROR: failed to copy crud.js to local static/js\n";
-    copy( file( $cx_crud_yui_tt_path, 'static', 'js', 'json.js' ),
-        file( $js_dir, 'json.js' ) )
+    copy( file( $cx_crud_yui_tt_path, 'static', 'js', 'json.js' ) . '',
+        file( $js_dir, 'json.js' ) . '' )
         or warn "ERROR: failed to copy json.js to local static/js\n";
-    copy( file( $cx_crud_yui_tt_path, 'static', 'css', 'crud.css' ),
-        file( $css_dir, 'crud.css' ) )
+    copy( file( $cx_crud_yui_tt_path, 'static', 'css', 'crud.css' ) . '',
+        file( $css_dir, 'crud.css' ) . '' )
         or warn "ERROR: failed to copy crud.css to local static/css\n";
 
     # all the css files
     my $css_base_dir = dir( $cx_crud_yui_tt_path, 'static', 'css', 'crud' );
     while ( my $css_file = $css_base_dir->next ) {
         next unless -f $css_file;
-        copy( $css_file, file( $css_crud_dir, $css_file->basename ) )
+        copy( $css_file . '' , file( $css_crud_dir, $css_file->basename ) . '' )
             or warn "ERROR: failed to copy $css_file to $css_crud_dir\n";
     }
 
